@@ -29,6 +29,7 @@ PHENIXVERSIONFILENAME = './phenix_env.sh'
 PHENIXVERSION = '1.13' # plugin version
 PHENIXVERSION18 = '1.18' # september 2020
 PHENIXVERSION19 = '1.19' # june 2021
+PHENIXVERSION20 = '1.20' # march 2022
 
 #python used to run phenix scripts
 PHENIX_PYTHON = 'phenix.python '  # keep the ending space
@@ -48,6 +49,10 @@ EMRINGER = 'emringer.py'
 GETVERSION = 'phenix.version'
 DOCKINMAP = 'dock_in_map.py'
 SYMMETRY = 'map_symmetry.py'
+PROCESS = 'process_predicted_model.py'
+DOCKPREDICTEDMODEL = 'dock_predicted_model.py'
+REBUILDDOCKPREDICTEDMODEL = 'rebuild_predicted_model.py'
+DOCKANDREBUILD = 'dock_and_rebuild.py'
 mapBinarytoDirectory ={
     REALSPACEREFINE : PHENIX_SCRIPT_PATH2,
     SUPERPOSE : PHENIX_SCRIPT_PATH2,
@@ -57,6 +62,10 @@ mapBinarytoDirectory ={
     EMRINGER : PHENIX_SCRIPT_PATH1,
     GETVERSION: PHENIX_GETVERSION_PATH,
     DOCKINMAP: PHENIX_SCRIPT_PATH2,
-    SYMMETRY: PHENIX_SCRIPT_PATH2
+    SYMMETRY: PHENIX_SCRIPT_PATH2,
+    PROCESS: PHENIX_SCRIPT_PATH2,
+    DOCKPREDICTEDMODEL: PHENIX_SCRIPT_PATH2,
+    REBUILDDOCKPREDICTEDMODEL: PHENIX_SCRIPT_PATH2,
+    DOCKANDREBUILD: PHENIX_SCRIPT_PATH2
 }
 DISPLAY='display'
\ No newline at end of file
