@@ -94,7 +94,8 @@ class PhenixProtRunDockInMap(EMProtocol):
     def runDockInMapStep(self):
         # starting structure
         atomStructFileName = self.inputStructure.get().getFileName()
-        atomStruct = os.getcwd() + "/" + atomStructFileName
+        # atomStruct = os.getcwd() + "/" + atomStructFileName
+        atomStruct = atomStructFileName
         # starting map (.mrc)
         mapFile = self.DOCKINMAPFILE
         vol = os.getcwd() + "/" + self._getExtraPath(mapFile)
@@ -190,8 +191,8 @@ class PhenixProtRunDockInMap(EMProtocol):
 
     def is_tool(self, name):
         """Check whether `name` is on PATH."""
-        from distutils.spawn import find_executable
-        return find_executable(name) is not None
+        from shutil import which
+        return which(name) is not None
 
     def _getDockInMapOutput(self):
         outAtomStructName = os.getcwd() + "/" +\
