@@ -300,8 +300,8 @@ dataDict['_residues_dict'] = dictResidue
 
     def is_tool(self, name):
         """Check whether `name` is on PATH."""
-        from distutils.spawn import find_executable
-        return find_executable(name) is not None
+        from shutil import which
+        return which(name) is not None
 
     def _writeArgsEMRinger(self, atomStruct, vol):
         args = " "
