@@ -33,7 +33,7 @@ from phenix.protocols.protocol_real_space_refine import (PhenixProtRunRSRefine,
 from phenix.protocols.protocol_molprobity import PhenixProtRunMolprobity
 from phenix.protocols.protocol_validation_cryoem import PhenixProtRunValidationCryoEM
 from pyworkflow.tests import *
-from phenix import Plugin, PHENIXVERSION, PHENIXVERSION18, PHENIXVERSION19
+from phenix import Plugin, PHENIXVERSION, PHENIXVERSION18, PHENIXVERSION19, PHENIXVERSION20
 import json
 from phenix.protocols.protocol_emringer import PhenixProtRunEMRinger
 from phenix.protocols.protocol_superpose_pdbs import PhenixProtRunSuperposePDBs
@@ -396,6 +396,14 @@ class TestPhenixPdbCif(TestImportData):
                                       clashScore=3.87,
                                       overallScore=1.59,
                                       protRSRefine=protRSRefine)
+        elif Plugin.getPhenixVersion() == PHENIXVERSION20:
+            self.checkRSRefineResults(ramOutliers=0.00,
+                                      ramFavored=98.59,
+                                      rotOutliers=1.30,
+                                      cbetaOutliers=0,
+                                      clashScore=4.31,
+                                      overallScore=1.30,
+                                      protRSRefine=protRSRefine)
         else:
             self.checkRSRefineResults(ramOutliers=0.00,
                                       ramFavored=96.11,
@@ -442,6 +450,14 @@ class TestPhenixPdbCif(TestImportData):
                                 clashScore=3.87,
                                 overallScore=1.59,
                                 protMolProbity=protMolProbity2)
+        elif Plugin.getPhenixVersion() == PHENIXVERSION20:
+            self.checkRSRefineResults(ramOutliers=0.00,
+                                      ramFavored=98.59,
+                                      rotOutliers=1.30,
+                                      cbetaOutliers=0,
+                                      clashScore=4.31,
+                                      overallScore=1.30,
+                                      protRSRefine=protRSRefine)
         else:
             self.checkMPResults(ramOutliers=0.00,
                                 ramFavored=96.11,
@@ -483,6 +499,14 @@ class TestPhenixPdbCif(TestImportData):
                                        clashScore=3.87,
                                        overallScore=1.59,
                                        protValCryoEM=protValCryoEM)
+        if Plugin.getPhenixVersion() == PHENIXVERSION20:
+            self.checkValCryoEMResults(ramOutliers=0.00,
+                                       ramFavored=98.59,
+                                       rotOutliers=1.30,
+                                       cbetaOutliers=0,
+                                       clashScore=4.42,
+                                       overallScore=1.31,
+                                       protValCryoEM=protValCryoEM)
         else:
             self.checkValCryoEMResults(ramOutliers=0.00,
                                       ramFavored=96.11,
@@ -585,6 +609,14 @@ class TestPhenixPdbCif(TestImportData):
                                       clashScore=3.87,
                                       overallScore=1.59,
                                       protRSRefine=protRSRefine)
+        elif Plugin.getPhenixVersion() == PHENIXVERSION20:
+            self.checkRSRefineResults(ramOutliers=0.00,
+                                      ramFavored=98.59,
+                                      rotOutliers=1.30,
+                                      cbetaOutliers=0,
+                                      clashScore=4.31,
+                                      overallScore=1.30,
+                                      protRSRefine=protRSRefine)
         else:
             # values obtained from phenix GUI v. 1.16
             # (minimization_global + adp)
@@ -633,6 +665,14 @@ class TestPhenixPdbCif(TestImportData):
                                 clashScore=3.87,
                                 overallScore=1.59,
                                 protMolProbity=protMolProbity2)
+        elif Plugin.getPhenixVersion() == PHENIXVERSION20:
+            self.checkRSRefineResults(ramOutliers=0.00,
+                                      ramFavored=98.59,
+                                      rotOutliers=1.30,
+                                      cbetaOutliers=0,
+                                      clashScore=4.31,
+                                      overallScore=1.30,
+                                      protRSRefine=protRSRefine)
         else:
             self.checkMPResults(ramOutliers=0.00,
                                 ramFavored=96.11,
@@ -676,6 +716,14 @@ class TestPhenixPdbCif(TestImportData):
                                     clashScore=3.87,
                                     overallScore=1.59,
                                     protValCryoEM=protValCryoEM)
+        if Plugin.getPhenixVersion() == PHENIXVERSION20:
+            self.checkValCryoEMResults(ramOutliers=0.00,
+                                    ramFavored=98.59,
+                                    rotOutliers=1.30,
+                                    cbetaOutliers=0,
+                                    clashScore=4.42,
+                                    overallScore=1.31,
+                                    protValCryoEM=protValCryoEM)
         else:
             self.checkValCryoEMResults(ramOutliers=0.00,
                                       ramFavored=96.11,
@@ -780,6 +828,14 @@ class TestPhenixPdbCif(TestImportData):
                                       clashScore=3.87,
                                       overallScore=1.59,
                                       protRSRefine=protRSRefine)
+        elif Plugin.getPhenixVersion() == PHENIXVERSION20:
+            self.checkRSRefineResults(ramOutliers=0.00,
+                                      ramFavored=98.59,
+                                      rotOutliers=1.30,
+                                      cbetaOutliers=0,
+                                      clashScore=4.31,
+                                      overallScore=1.30,
+                                      protRSRefine=protRSRefine)
         else:
             # values obtained from phenix GUI v. 1.16
             # (minimization_global + adp)
@@ -828,6 +884,14 @@ class TestPhenixPdbCif(TestImportData):
                                 clashScore=3.87,
                                 overallScore=1.59,
                                 protMolProbity=protMolProbity2)
+        elif Plugin.getPhenixVersion() == PHENIXVERSION20:
+            self.checkRSRefineResults(ramOutliers=0.00,
+                                      ramFavored=98.59,
+                                      rotOutliers=1.30,
+                                      cbetaOutliers=0,
+                                      clashScore=4.31,
+                                      overallScore=1.30,
+                                      protRSRefine=protRSRefine)
         else:
             self.checkMPResults(ramOutliers=0.00,
                                 ramFavored=96.11,
@@ -871,6 +935,14 @@ class TestPhenixPdbCif(TestImportData):
                                        clashScore=3.87,
                                        overallScore=1.59,
                                        protValCryoEM=protValCryoEM)
+        if Plugin.getPhenixVersion() == PHENIXVERSION20:
+            self.checkValCryoEMResults(ramOutliers=0.00,
+                                       ramFavored=98.59,
+                                       rotOutliers=1.30,
+                                       cbetaOutliers=0,
+                                       clashScore=4.42,
+                                       overallScore=1.31,
+                                       protValCryoEM=protValCryoEM)
         else:
             self.checkValCryoEMResults(ramOutliers=0.00,
                                       ramFavored=96.11,
